==> json-schema-for-humans-0.33.0.tar.gz: json-schema-for-humans-0.33.0/docs/examples/examples_md_nested_default/defaults.md <==
# Schema Docs

- [1. [Optional] Property root > a](#a)
- [2. [Optional] Property root > b](#b)

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

<details>
<summary><strong> <a name="a"></a>1. [Optional] Property root > a</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Default**               | `"Default from a"`                                                        |
| **Defined in**            | #/definitions/common                                                      |
|                           |                                                                           |

**Description:** Description of a

</blockquote>
</details>

<details>
<summary><strong> <a name="b"></a>2. [Optional] Property root > b</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Default**               | `"Default from b"`                                                        |
| **Same definition as**    | `[a](#a)`                                                                 |
|                           |                                                                           |

**Description:** A common description

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date

==> json-schema-for-humans-0.34.1.tar.gz: json-schema-for-humans-0.34.1/docs/examples/examples_md_nested_default/defaults.md <==
# Schema Docs

- [1. [Optional] Property root > a](#a)
- [2. [Optional] Property root > b](#b)

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

<details>
<summary><strong> <a name="a"></a>1. [Optional] Property root > a</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Default**               | `"Default from a"`                                                        |
| **Defined in**            | #/definitions/common                                                      |
|                           |                                                                           |

**Description:** Description of a

</blockquote>
</details>

<details>
<summary><strong> <a name="b"></a>2. [Optional] Property root > b</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Default**               | `"Default from b"`                                                        |
| **Same definition as**    | [a](#a)                                                                   |
|                           |                                                                           |

**Description:** A common description

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date
